@@ -7,7 +7,7 @@ package MarpaX::ESLIF::Grammar::Properties;
 
 our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
-our $VERSION = '5.0.7'; # VERSION
+our $VERSION = '6.0.10'; # VERSION
 
 
 #
@@ -24,6 +24,7 @@ sub new {
                    maxLevel            => $args{maxLevel},
                    description         => $args{description},
                    latm                => $args{latm},
+                   discardIsFallback   => $args{discardIsFallback},
                    defaultSymbolAction => $args{defaultSymbolAction},
                    defaultRuleAction   => $args{defaultRuleAction},
                    defaultEventAction  => $args{defaultEventAction},
@@ -75,6 +76,18 @@ sub getLatm {
 }
 
 
+sub isDiscardIsFallback {
+  my ($self) = @_;
+
+  return $self->{discardIsFallback}
+}
+
+
+sub getDiscardIsFallback {
+  goto &isDiscardIsFallback
+}
+
+
 sub getDefaultSymbolAction {
   my ($self) = @_;
 
@@ -158,7 +171,7 @@ MarpaX::ESLIF::Grammar::Properties - ESLIF Grammar Properties
 
 =head1 VERSION
 
-version 5.0.7
+version 6.0.10
 
 =head1 SYNOPSIS
 
@@ -200,8 +213,8 @@ version 5.0.7
   whitespaces ::= WHITESPACES
   comment ::= /(?:(?:(?:\/\/)(?:[^\n]*)(?:\n|\z))|(?:(?:\/\*)(?:(?:[^\*]+|\*(?!\/))*)(?:\*\/)))/u
 
-  :lexeme ::= NUMBER pause => before event => ^NUMBER
-  :lexeme ::= NUMBER pause => after  event => NUMBER$
+  :symbol ::= NUMBER pause => before event => ^NUMBER
+  :symbol ::= NUMBER pause => after  event => NUMBER$
 
   :desc      ~ 'Calculator Tokens'
   NUMBER     ~ /[\d]+/   name => 'NUMBER Lexeme'
@@ -237,6 +250,10 @@ Grammar description
 
 Grammar is in LATM (Longest Accepted Token Mode) ?
 
+=item discardIsFallback
+
+Grammar's :discard is a fallback
+
 =item defaultSymbolAction
 
 Grammar default symbol action
@@ -299,6 +316,14 @@ Returns a boolean that indicates if this grammar is in the LATM (Longest Accepta
 
 Alias to isLatm()
 
+=head2 $self->isDiscardIsFallback
+
+Returns a boolean that returns the grammar's discard-is-fallback setting
+
+=head2 $self->getDiscardIsFallback
+
+Alias to isDiscardIsFallback()
+
 =head2 $self->getDefaultSymbolAction
 
 Returns grammar's default symbol action, never null
