@@ -14,20 +14,26 @@ sub _ALLOCATE {
         my ($class, $eslif, %options) = @_;
 
         my $type = $options{type} // croak 'type must be defined';
-        my $pattern = $options{pattern} // croak 'pattern must be defined';
-        my $encoding = $options{encoding};
-        my $modifiers = $options{modifiers};
 
-        return ($type eq 'string')
-            ?
-            MarpaX::ESLIF::Symbol->string_allocate($eslif, $pattern, bytes::length($pattern), $encoding, $modifiers)
-            :
-            (($type eq 'regex')
-             ?
-             MarpaX::ESLIF::Symbol->regex_allocate($eslif, $pattern, bytes::length($pattern), $encoding, $modifiers)
-             :
-             croak "Type must be 'string' or 'regex'"
-            )
+        if (($type eq 'string') or ($type eq 'regex')) {
+            my $pattern = $options{pattern} // croak 'pattern must be defined';
+            my $encoding = $options{encoding};
+            my $modifiers = $options{modifiers};
+
+            return
+                ($type eq 'string')
+                ?
+                MarpaX::ESLIF::Symbol->string_allocate($eslif, $pattern, bytes::length($pattern), $encoding, $modifiers)
+                :
+                MarpaX::ESLIF::Symbol->regex_allocate($eslif, $pattern, bytes::length($pattern), $encoding, $modifiers)
+        } elsif ($type eq 'meta') {
+            my $grammar = $options{grammar} // croak 'grammar must be defined';
+            my $symbol = $options{symbol} // croak 'symbol must be defined';
+
+            return MarpaX::ESLIF::Symbol->meta_allocate($eslif, $grammar, $symbol)
+        } else {
+            croak "Type must be 'string', 'regex' or 'meta'"
+        }
     }
 }
 sub _DISPOSE  { return \&MarpaX::ESLIF::Symbol::dispose }
@@ -36,25 +42,44 @@ sub _EQ {
         my ($class, $args_ref, $eslif, %options) = @_;
 
         my $type = $options{type} // croak 'type must be defined';
-        my $pattern = $options{pattern} // croak 'pattern must be defined';
-        my $encoding = $options{encoding};
-        my $modifiers = $options{modifiers};
 
-        my $definedEncoding = defined($encoding); # It is legal to create a symbol with no encoding
-        my $definedModifiers = defined($modifiers); # It is legal to create a symbol with no modifier
+        if (($type eq 'string') or ($type eq 'regex')) {
 
-        my $_definedEncoding = defined($args_ref->[3]);
-        my $_definedModifiers = defined($args_ref->[4]);
-        return $_ if
-            $eslif == $args_ref->[0]
-            &&
-            $type eq $args_ref->[1]
-            &&
-            $pattern eq $args_ref->[2]
-            &&
-            ((! $definedEncoding && ! $_definedEncoding) || ($definedEncoding && $_definedEncoding && ($encoding eq $args_ref->[3])))
-            &&
-            ((! $definedModifiers && ! $_definedModifiers) || ($definedModifiers && $_definedModifiers && ($modifiers eq $args_ref->[4])))
+            my $pattern = $options{pattern} // croak 'pattern must be defined';
+            my $encoding = $options{encoding};
+            my $modifiers = $options{modifiers};
+
+            my $definedEncoding = defined($encoding); # It is legal to create a symbol with no encoding
+            my $definedModifiers = defined($modifiers); # It is legal to create a symbol with no modifier
+
+            my $_definedEncoding = defined($args_ref->[3]);
+            my $_definedModifiers = defined($args_ref->[4]);
+            return $_ if
+                $eslif == $args_ref->[0]
+                &&
+                $type eq $args_ref->[1]
+                &&
+                $pattern eq $args_ref->[2]
+                &&
+                ((! $definedEncoding && ! $_definedEncoding) || ($definedEncoding && $_definedEncoding && ($encoding eq $args_ref->[3])))
+                &&
+                ((! $definedModifiers && ! $_definedModifiers) || ($definedModifiers && $_definedModifiers && ($modifiers eq $args_ref->[4])))
+
+        } elsif ($type eq 'meta') {
+            my $grammar = $options{grammar} // croak 'grammar must be defined';
+            my $symbol = $options{symbol} // croak 'symbol must be defined';
+
+            return $_ if
+                $eslif == $args_ref->[0]
+                &&
+                $type eq $args_ref->[1]
+                &&
+                $grammar == $args_ref->[2]
+                &&
+                $symbol eq $args_ref->[3]
+        } else {
+            croak "Type must be 'string', 'regex' or 'meta'"
+        }
     }
 }
 
@@ -62,7 +87,7 @@ sub _EQ {
 
 our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
-our $VERSION = '5.0.7'; # VERSION
+our $VERSION = '6.0.10'; # VERSION
 
 
 1;
@@ -79,7 +104,7 @@ MarpaX::ESLIF::Symbol - MarpaX::ESLIF's symbol
 
 =head1 VERSION
 
-version 5.0.7
+version 6.0.10
 
 =head1 SYNOPSIS
 
@@ -92,6 +117,11 @@ version 5.0.7
   # In ESLIF, a regex is anchored by default
   #
   my $regexSymbol = MarpaX::ESLIF::Symbol->new($eslif, type => 'regex', pattern => 'Regex.*Pattern', modifiers => 'A');
+  my $metaSymbol = MarpaX::ESLIF::Symbol->new($eslif, type => 'meta',
+                                                      grammar => MarpaX::ESLIF::Grammar->new(
+                                                                   $eslif,
+                                                                   "<something> ::= <SOMETHING>\n<SOMETHING> ~ 'that'")
+                                                      symbol => 'SOMETHING');
 
   if (defined(my $match = $stringSymbol->try('String Pattern here'))) {
       print "==> String match: $match\n";
@@ -101,7 +131,11 @@ version 5.0.7
       print "==> Regex match: $match\n";
   }
 
-External symbols can be of type C<string> or C<regex>. They can be used agains a L<MarpaX::ESLIF::Recognizer> or any external input.
+  if (defined(my $match = $metaSymbol->try('something'))) {
+      print "==> Meta match: $match\n";
+  }
+
+External symbols can be of type C<string>, C<regex> or C<meta>. They can be used agains a L<MarpaX::ESLIF::Recognizer> or any external input.
 
 A string pattern I<must> follow ESLIF)s BNF, i.e. start and ends with:
 
@@ -115,6 +149,8 @@ A string pattern I<must> follow ESLIF)s BNF, i.e. start and ends with:
 
 =back
 
+A meta symbol I<must> be a lexeme in the given external grammar.
+
 =head1 DESCRIPTION
 
 MarpaX::ESLIF::Symbol allows to create external symbols on demand
@@ -129,19 +165,19 @@ Returns a symbol instance, noted C<$symbol> later. C<%options> is a hash that co
 
 =item C<type>
 
-Value must be "string" or "regex". Required.
+Value must be "string", "regex" or "meta". Required.
 
 =item C<pattern>
 
-Value is the pattern content. Required.
+Value is the pattern content. Required for "string" and "regex" types.
 
 =item C<encoding>
 
-Value is the pattern encoding. Optional.
+Value is the pattern encoding. Optional for "string" and "regex" types.
 
 =item C<modifiers>
 
-Value is a string containing modifiers. Optional.
+Value is a string containing modifiers. Optional for "string" and "regex" types.
 
 It must follow the specification of the I<Terminals> section of L<MarpaX::ESLIF::BNF>:
 
@@ -169,6 +205,14 @@ Note that a string pattern accepts only the C<i> and C<c> modifiers.
 
 =back
 
+=item C<grammar>
+
+Value is an external grammar. Required for "meta" type.
+
+=item C<symbol>
+
+Value is a lexeme in the external grammar. Required for "meta" type.
+
 =head2 $symbol->try($eslif, $scalar)
 
 Try to match the external symbol C<$symbol> on C<$scalar>, that can be anything. Return C<undef> if failure, the matched string if success.
